## $Id: studycourse.py 10200 2013-05-22 15:59:20Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Container which holds the data of the student study courses
and contains the (student) study level objects.
"""
import grok
from zope.interface import implementedBy
from waeup.kofa.students.studycourse import StudentStudyCourseFactory
from waeup.kofa.utils.helpers import attrs_to_fields
from waeup.kofa.students.interfaces import IStudentNavigation
from waeup.kofa.students.workflow import CLEARED, RETURNING, PAID
from kofacustom.nigeria.students.studycourse import NigeriaStudentStudyCourse
from waeup.uniben.students.interfaces import ICustomStudentStudyCourse

class CustomStudentStudyCourse(NigeriaStudentStudyCourse):
    """This is a container for study levels.
    """
    grok.implements(ICustomStudentStudyCourse, IStudentNavigation)
    grok.provides(ICustomStudentStudyCourse)

    @property
    def is_postgrad(self):
        if self.certificate is None:
            return False
        return self.certificate.study_mode.startswith('pg') or \
            self.certificate.study_mode.startswith('special_pg')

    @property
    def is_special_postgrad(self):
        if self.certificate is None:
            return False
        return self.certificate.study_mode.startswith('special_pg')

CustomStudentStudyCourse = attrs_to_fields(CustomStudentStudyCourse)

class CustomStudentStudyCourseFactory(StudentStudyCourseFactory):
    """A factory for student study courses.
    """

    def __call__(self, *args, **kw):
        return CustomStudentStudyCourse()

    def getInterfaces(self):
        return implementedBy(CustomStudentStudyCourse)
